@@ -27,15 +27,15 @@ from health_azure import AzureRunInfo, submit_to_azure_if_needed  # noqa: E402
 from health_azure.datasets import create_dataset_configs  # noqa: E402
 from health_azure.logging import logging_to_stdout   # noqa: E402
 from health_azure.paths import is_himl_used_from_git_repo  # noqa: E402
-from health_azure.utils import (get_workspace, is_local_rank_zero, merge_conda_files,  # noqa: E402
-                                set_environment_variables_for_multi_node, create_argparser, parse_arguments,
-                                ParserResult, apply_overrides)
+from health_azure.utils import (get_workspace, is_local_rank_zero, is_running_in_azure_ml,  # noqa: E402
+                                merge_conda_files, set_environment_variables_for_multi_node,
+                                create_argparser, parse_arguments, ParserResult, apply_overrides)
 
 from health_ml.experiment_config import ExperimentConfig  # noqa: E402
 from health_ml.lightning_container import LightningContainer  # noqa: E402
 from health_ml.run_ml import MLRunner  # noqa: E402
 from health_ml.utils import fixed_paths  # noqa: E402
-from health_ml.utils.common_utils import (check_conda_environments, get_all_environment_files,  # noqa: E402
+from health_ml.utils.common_utils import (check_conda_environment, choose_conda_env_file,  # noqa: E402
                                           get_all_pip_requirements_files,
                                           is_linux)
 from health_ml.utils.config_loader import ModelConfigLoader  # noqa: E402
@@ -156,18 +156,13 @@ class Runner:
         """
         Runs sanity checks on the whole experiment.
         """
-        if not self.experiment_config.azureml:
+        if not self.experiment_config.cluster:
             if self.lightning_container.hyperdrive:
-                logging.info("You have turned on HyperDrive for parameter tuning. This can "
-                             "only be run in AzureML. We switched on submitting to AzureML.")
-                self.experiment_config.azureml = True
+                raise ValueError("HyperDrive for hyperparameters tuning is only supported when submitting the job to "
+                                 "AzureML. You need to specify a compute cluster with the argument --cluster.")
             if self.lightning_container.is_crossvalidation_enabled:
-                logging.info("You have turned on cross-validation. This can "
-                             "only be run in AzureML. We switched on submitting to AzureML.")
-                self.experiment_config.azureml = True
-            if self.experiment_config.cluster:
-                logging.info("You have provided a compute cluster name, hence we switched on submitting to AzureML.")
-                self.experiment_config.azureml = True
+                raise ValueError("Cross-validation is only supported when submitting the job to AzureML."
+                                 "You need to specify a compute cluster with the argument --cluster.")
 
     def additional_run_tags(self, script_params: List[str]) -> Dict[str, str]:
         """
@@ -227,7 +222,7 @@ class Runner:
         # Get default datastore from the provided workspace. Authentication can take a few seconds, hence only do
         # that if we are really submitting to AzureML.
         workspace: Optional[Workspace] = None
-        if self.experiment_config.azureml:
+        if self.experiment_config.cluster:
             try:
                 workspace = get_workspace()
             except ValueError:
@@ -239,30 +234,28 @@ class Runner:
         all_local_datasets = [Path(p) for p in local_datasets] if len(local_datasets) > 0 else []
         # When running in AzureML, respect the commandline flag for mounting. Outside of AML, we always mount
         # datasets to be quicker.
-        use_mounting = self.experiment_config.mount_in_azureml if self.experiment_config.azureml else True
+        use_mounting = self.experiment_config.mount_in_azureml if self.experiment_config.cluster else True
         input_datasets = \
             create_dataset_configs(all_azure_dataset_ids=self.lightning_container.azure_datasets,
                                    all_dataset_mountpoints=self.lightning_container.dataset_mountpoints,
                                    all_local_datasets=all_local_datasets,  # type: ignore
                                    datastore=default_datastore,
                                    use_mounting=use_mounting)
-        if self.lightning_container.is_crossvalidation_enabled and not self.experiment_config.azureml:
-            raise ValueError("Cross-validation is only supported when submitting the job to AzureML.")
         hyperdrive_config = self.lightning_container.get_hyperdrive_config()
-        temp_conda: Optional[Path] = None
+        temp_conda_file: Optional[Path] = None
         try:
-            if self.experiment_config.azureml:
-                conda_files = get_all_environment_files(root_folder,
-                                                        additional_files=self.lightning_container.additional_env_files)
-                check_conda_environments(conda_files)
+            if self.experiment_config.cluster and not is_running_in_azure_ml():
+                env_file = choose_conda_env_file(env_file=self.experiment_config.conda_env)
+                logging.info(f"Using this Conda environment definition: {env_file}")
+                check_conda_environment(env_file)
                 # This adds all pip packages required by hi-ml and hi-ml-azure in case the code is used directly from
                 # source (submodule) rather than installed as a package.
                 pip_requirements_files = get_all_pip_requirements_files()
 
                 # Merge the project-specific dependencies with the packages and write unified definition to temp file.
-                if len(conda_files) > 1 or len(pip_requirements_files) > 0:
-                    temp_conda = root_folder / f"temp_environment-{uuid.uuid4().hex[:8]}.yml"
-                    merge_conda_files(conda_files, temp_conda, pip_files=pip_requirements_files)
+                if len(pip_requirements_files) > 0:
+                    temp_conda_file = root_folder / f"temp_environment-{uuid.uuid4().hex[:8]}.yml"
+                    merge_conda_files([env_file], temp_conda_file, pip_files=pip_requirements_files)
 
                 if not self.experiment_config.cluster:
                     raise ValueError("You need to specify a cluster name via '--cluster NAME' to submit "
@@ -271,7 +264,7 @@ class Runner:
                     entry_script=entry_script,
                     snapshot_root_directory=root_folder,
                     script_params=script_params,
-                    conda_environment_file=temp_conda or conda_files[0],
+                    conda_environment_file=temp_conda_file or env_file,
                     aml_workspace=workspace,
                     compute_cluster_name=self.experiment_config.cluster,
                     environment_variables=environment_variables,
@@ -281,7 +274,7 @@ class Runner:
                     num_nodes=self.experiment_config.num_nodes,
                     wait_for_completion=self.experiment_config.wait_for_completion,
                     ignored_folders=[],
-                    submit_to_azureml=self.experiment_config.azureml,
+                    submit_to_azureml=bool(self.experiment_config.cluster),
                     docker_base_image=DEFAULT_DOCKER_BASE_IMAGE,
                     docker_shm_size=self.experiment_config.docker_shm_size,
                     hyperdrive_config=hyperdrive_config,
@@ -302,8 +295,8 @@ class Runner:
                     input_datasets=input_datasets,  # type: ignore
                     submit_to_azureml=False)
         finally:
-            if temp_conda and temp_conda.is_file():
-                temp_conda.unlink()
+            if temp_conda_file and temp_conda_file.is_file():
+                temp_conda_file.unlink()
         # submit_to_azure_if_needed calls sys.exit after submitting to AzureML. We only reach this when running
         # the script locally or in AzureML.
         return azure_run_info
